@@ -97,23 +97,23 @@ def get_projects(changes_from_date=None):
     return items
 
 
-def create_income(operation: Operation):
+def create_income(operation: IncomeOutcomeOperation):
     path = f'/api/v1/operations/income'
-    data = operation.params
+    data = operation.dict()
     res, _ = pf_interaction.request('post', path, data=data)
     return res.json()['data']
 
 
-def create_outcome(operation: Operation):
+def create_outcome(operation: IncomeOutcomeOperation):
     path = f'/api/v1/operations/outcome'
-    data = operation.params
+    data = operation.dict()
     res, _ = pf_interaction.request('post', path, data=data)
     return res.json()['data']
 
 
 def create_move_operation(operation: MoveOperation):
     path = f'/api/v1/operations/move'
-    data = operation.params
+    data = operation.dict()
     res, _ = pf_interaction.request('post', path, data=data)
     return res.json()['data']
 
